@@ -7,7 +7,7 @@ from the library without having to set the sys.path.
 """
 import sys
 
-from exactly_lib.default.default_main_program_setup import main
+from exactly_lib.cli_default.default_main_program_setup import main
 
 exit_status = main()
 sys.exit(exit_status)
