@@ -1,7 +1,7 @@
 from exactly_lib.common.instruction_setup import instruction_set_from_name_and_setup_constructor_list
 from exactly_lib.definitions.test_case.instructions import instruction_names
 from exactly_lib.impls.instructions.cleanup import define_symbol, change_dir, copy, \
-    env, run, new_file, new_dir, shell, sys_cmd
+    env, run, new_file, new_dir, shell, sys_cmd, timeout
 
 INSTRUCTIONS = instruction_set_from_name_and_setup_constructor_list(
     [
@@ -9,6 +9,7 @@ INSTRUCTIONS = instruction_set_from_name_and_setup_constructor_list(
         (instruction_names.NEW_FILE_INSTRUCTION_NAME, new_file.setup),
         (instruction_names.NEW_DIR_INSTRUCTION_NAME, new_dir.setup),
         (instruction_names.COPY_INSTRUCTION_NAME, copy.setup),
+        (instruction_names.TIMEOUT_INSTRUCTION_NAME, timeout.setup),
         (instruction_names.ENV_VAR_INSTRUCTION_NAME, env.setup),
         (instruction_names.RUN_INSTRUCTION_NAME, run.setup),
         (instruction_names.CHANGE_DIR_INSTRUCTION_NAME, change_dir.setup),
