@@ -4,7 +4,7 @@ from exactly_lib.common.help.syntax_contents_structure import InvokationVariant,
 from exactly_lib.definitions.cross_ref.app_cross_ref import SeeAlsoTarget
 from exactly_lib.definitions.doc_format import syntax_text
 from exactly_lib.util.textformat.structure.core import StringText, ParagraphItem
-from exactly_lib.util.textformat.structure.document import Section
+from exactly_lib.util.textformat.structure.document import Section, SectionContents
 
 
 class InstructionDocumentation:
@@ -13,8 +13,7 @@ class InstructionDocumentation:
     à la man page.
     """
 
-    def __init__(self,
-                 instruction_name: str):
+    def __init__(self, instruction_name: str):
         self._instruction_name = instruction_name
 
     def instruction_name(self) -> str:
@@ -39,6 +38,12 @@ class InstructionDocumentation:
     def syntax_element_descriptions(self) -> Sequence[SyntaxElementDescription]:
         return []
 
+    def outcome(self) -> SectionContents:
+        return SectionContents.empty()
+
+    def notes(self) -> SectionContents:
+        return SectionContents.empty()
+
     def see_also_targets(self) -> List[SeeAlsoTarget]:
         """
         :returns: A new list of see-also-targets, which may contain duplicate elements.
