@@ -1,18 +1,41 @@
 from typing import Optional
 
 from exactly_lib import program_info
-from exactly_lib.definitions import formatting, misc_texts
+from exactly_lib.definitions import formatting, misc_texts, os_proc_env
+from exactly_lib.definitions.cross_ref.app_cross_ref import CrossReferenceId
 from exactly_lib.definitions.cross_ref.concrete_cross_refs import EntityCrossReferenceId
 from exactly_lib.definitions.cross_ref.name_and_cross_ref import EntityTypeNames, \
     SingularAndPluralAndAcronymNameAndCrossReferenceId
 from exactly_lib.definitions.entity import all_entity_types
 from exactly_lib.definitions.test_case import phase_names, phase_infos
 from exactly_lib.section_document import defs as syntax_defs
-from exactly_lib.util.str_.name import NameWithGender, an_name_with_plural_s, a_name_with_plural_s
+from exactly_lib.util.str_.name import NameWithGender, an_name_with_plural_s, a_name_with_plural_s, \
+    NameWithGenderWithFormatting
 
 _CURRENT_DIRECTORY_SINGULAR = 'current directory'
 
 
+class ConceptWDefaultCrossReferenceId(SingularAndPluralAndAcronymNameAndCrossReferenceId):
+    def __init__(self,
+                 name: NameWithGenderWithFormatting,
+                 single_line_description_str: str,
+                 cross_reference_target: CrossReferenceId,
+                 default: str,
+                 acronym: Optional[str] = None,
+                 ):
+        super().__init__(
+            name,
+            single_line_description_str,
+            cross_reference_target,
+            acronym
+        )
+        self._default = default
+
+    @property
+    def default(self) -> str:
+        return self._default
+
+
 def concept_cross_ref(concept_name: str) -> EntityCrossReferenceId:
     return EntityCrossReferenceId(all_entity_types.CONCEPT_ENTITY_TYPE_NAMES,
                                   concept_name)
@@ -39,6 +62,7 @@ _FORMAT_MAP = {
     'program_name': formatting.program_name(program_info.PROGRAM_NAME),
     'phase': phase_names.PHASE_NAME_DICTIONARY,
     'act': phase_infos.ACT.name,
+    'assert': phase_infos.ASSERT.name,
     'actor': formatting.concept(all_entity_types.ACTOR_ENTITY_TYPE_NAMES.name.singular),
     'action_to_check': formatting.concept(ACTION_TO_CHECK_NAME.singular),
     'current_directory_concept': formatting.concept(_CURRENT_DIRECTORY_SINGULAR),
@@ -84,13 +108,22 @@ SDS_CONCEPT_INFO = name_and_ref_target(
 
 CURRENT_WORKING_DIRECTORY_CONCEPT_INFO = name_and_ref_target(
     NameWithGender('a', _CURRENT_DIRECTORY_SINGULAR, 'current directories'),
-    _format('The current directory of the environment in which instruction and {os_process:s} are executed.'),
+    _format('The current directory of the environment in which instructions and {os_process:s} are executed.'),
     'CD',
 )
 
-ENVIRONMENT_VARIABLE_CONCEPT_INFO = name_and_ref_target(
-    an_name_with_plural_s('environment variable'),
-    _format('OS environment variables available to processes executed from within a test case.')
+ENVIRONMENT_VARIABLE_CONCEPT_INFO = ConceptWDefaultCrossReferenceId(
+    formatting.concept_name_with_formatting(an_name_with_plural_s('environment variable')),
+    _format('OS environment variables available to {os_process:s} executed from within a test case.'),
+    concept_cross_ref('environment variable'),
+    _format('All OS environment variables set when {program_name} is started')
+)
+
+TIMEOUT_CONCEPT_INFO = ConceptWDefaultCrossReferenceId(
+    formatting.concept_name_with_formatting(a_name_with_plural_s('timeout')),
+    _format('Timeout of {os_process:s} executed from within a test case.'),
+    concept_cross_ref('timeout'),
+    os_proc_env.render_timeout_value(os_proc_env.TIMEOUT__DEFAULT)
 )
 
 PREPROCESSOR_CONCEPT_INFO = name_and_ref_target(
@@ -100,7 +133,7 @@ PREPROCESSOR_CONCEPT_INFO = name_and_ref_target(
 
 SHELL_SYNTAX_CONCEPT_INFO = name_and_ref_target(
     NameWithGender('a', 'shell syntax', "shell syntaxes"),
-    'Quoting of strings in command lines.'
+    'Quoting of {plain_string:s} in command lines.'.format(plain_string=misc_texts.PLAIN_STRING)
 )
 
 SUITE_REPORTER_CONCEPT_INFO = name_and_ref_target_for_entity_type(
@@ -125,7 +158,7 @@ ACTOR_CONCEPT_INFO = name_and_ref_target_for_entity_type(
 
 ACTION_TO_CHECK_CONCEPT_INFO = name_and_ref_target(
     ACTION_TO_CHECK_NAME,
-    _format('The action that is executed in the {act} phase.'),
+    _format('The action that is executed in the {act} phase and checked by the {assert} phase.'),
     'ATC',
 )
 
