@@ -20,3 +20,8 @@ DIR_WITHOUT_RELATIVITY_OPTIONS_ARGUMENT = a.Named('DIRECTORY')
 
 DESTINATION_PATH_ARGUMENT = a.Named('DESTINATION')
 SOURCE_PATH_ARGUMENT = a.Named('SOURCE')
+
+FILE_NAME_STRING = a.Named('FILE-NAME')
+
+FILE_NAME_STRING__SINGLE_MANDATORY = a.Single(a.Multiplicity.MANDATORY,
+                                              FILE_NAME_STRING)
