@@ -33,7 +33,6 @@ def execute(conf: ExecutionConfiguration,
     conf_phase_values = ConfPhaseValues(
         configuration_builder.actor,
         configuration_builder.hds,
-        configuration_builder.timeout_in_seconds,
     )
     partial_result = execution.execute(
         TestCase(test_case.setup_phase,
@@ -43,7 +42,7 @@ def execute(conf: ExecutionConfiguration,
                  test_case.cleanup_phase),
         conf,
         conf_phase_values,
-        StandardSetupSettingsHandler.new_empty(),
+        StandardSetupSettingsHandler.new_from_environ,
         is_keep_sandbox)
     return new_from_result_of_partial_execution(configuration_builder.test_case_status,
                                                 partial_result)
