@@ -1,6 +1,7 @@
 import itertools
 import os
-from typing import Sequence, Optional, Tuple
+from types import MappingProxyType
+from typing import Sequence, Optional, Tuple, Mapping, Callable
 
 from exactly_lib.execution import phase_file_space
 from exactly_lib.execution import phase_step
@@ -20,10 +21,13 @@ from exactly_lib.tcfs.sds import SandboxDs, construct_at
 from exactly_lib.test_case import phase_identifier
 from exactly_lib.test_case.phases.act.actor import ActionToCheck, Actor
 from exactly_lib.test_case.phases.cleanup import PreviousPhase
+from exactly_lib.test_case.phases.environ import OptionalEnvVarsDict
 from exactly_lib.test_case.phases.instruction_environment import InstructionEnvironmentForPreSdsStep, \
     InstructionEnvironmentForPostSdsStep
+from exactly_lib.test_case.phases.instruction_settings import InstructionSettings
 from exactly_lib.test_case.phases.setup.settings_handler import SetupSettingsHandler
 from exactly_lib.test_case.result.failure_details import FailureDetails
+from exactly_lib.util import functional
 from exactly_lib.util.file_utils.misc_utils import resolved_path_name
 from exactly_lib.util.name_and_value import NameAndValue
 from exactly_lib.util.process_execution.execution_elements import ProcessExecutionSettings
@@ -34,11 +38,11 @@ class Configuration(tuple):
     def __new__(cls,
                 conf_from_outside: ExecutionConfiguration,
                 conf_phase_values: ConfPhaseValues,
-                setup_settings_handler: SetupSettingsHandler,
+                mk_setup_settings_handler: Callable[[OptionalEnvVarsDict], SetupSettingsHandler],
                 ):
         return tuple.__new__(cls, (conf_from_outside,
                                    conf_phase_values,
-                                   setup_settings_handler))
+                                   mk_setup_settings_handler))
 
     @property
     def exe_conf(self) -> ExecutionConfiguration:
@@ -49,7 +53,7 @@ class Configuration(tuple):
         return self[1]
 
     @property
-    def setup_settings_handler(self) -> SetupSettingsHandler:
+    def mk_setup_settings_handler(self) -> Callable[[OptionalEnvVarsDict], SetupSettingsHandler]:
         return self[2]
 
 
@@ -82,12 +86,15 @@ def parse_atc_and_validate_symbols(actor: NameAndValue[Actor],
 class _PartialExecutor:
     def __init__(self,
                  conf: Configuration,
-                 test_case: TestCase):
+                 test_case: TestCase,
+                 ):
         self.conf = conf
         self.exe_conf = conf.exe_conf
         self.conf_values = conf.conf_phase_values
         self._test_case = test_case
-        self._setup_settings_builder = conf.setup_settings_handler
+        self._setup_settings_handler = conf.mk_setup_settings_handler(
+            functional.map_optional(dict, conf.exe_conf.environ)
+        )
         self._source_setup = None
         self._os_services = conf.exe_conf.os_services
         self._act_phase_executor = _initial_atc_executor()
@@ -99,6 +106,11 @@ class _PartialExecutor:
         self._phase_tmp_space_factory = None
         self._act_helper = ActHelper(conf.conf_phase_values.actor.name,
                                      test_case.act_phase)
+        self._instruction_settings = InstructionSettings(
+            functional.map_optional(dict, conf.exe_conf.environ),
+            conf.exe_conf.default_environ_getter,
+            conf.exe_conf.timeout_in_seconds,
+        )
 
     def execute(self) -> PartialExeResult:
         try:
@@ -206,8 +218,8 @@ class _PartialExecutor:
         self._action_to_check = atc
         self._instruction_environment_pre_sds = InstructionEnvironmentForPreSdsStep(
             self.conf_values.hds,
-            ProcessExecutionSettings(self.conf_values.timeout_in_seconds,
-                                     self.exe_conf.environ,
+            ProcessExecutionSettings(self._instruction_settings.timeout_in_seconds(),
+                                     self._env_vars__read_only(),
                                      ),
             symbols,
             self.exe_conf.mem_buff_size,
@@ -303,9 +315,10 @@ class _PartialExecutor:
     def _setup__main(self):
         run_instructions_phase_step(phase_step.SETUP__MAIN,
                                     phase_step_executors.SetupMainExecutor(
+                                        self._instruction_settings,
                                         self._os_services,
                                         self._post_sds_main_environments(phase_identifier.SETUP),
-                                        self._setup_settings_builder.builder),
+                                        self._setup_settings_handler.builder),
                                     self._test_case.setup_phase)
 
     def _setup__validate_post_setup(self):
@@ -327,7 +340,7 @@ class _PartialExecutor:
             ),
             env_for_non_validate_steps,
             self._os_services,
-            self._setup_settings_builder.as_act_execution_input(),
+            self._setup_settings_handler.as_atc_execution_input(),
             self.exe_conf.exe_atc_and_skip_assertions,
         )
 
@@ -350,6 +363,7 @@ class _PartialExecutor:
             phase_step.ASSERT__MAIN,
             phase_step_executors.AssertMainExecutor(
                 self._post_sds_main_environments(phase_identifier.ASSERT),
+                self._instruction_settings,
                 self._os_services),
             self._test_case.assert_phase)
 
@@ -358,6 +372,7 @@ class _PartialExecutor:
             phase_step.CLEANUP__MAIN,
             phase_step_executors.CleanupMainExecutor(
                 self._post_sds_main_environments(phase_identifier.CLEANUP),
+                self._instruction_settings,
                 previous_phase,
                 self._os_services),
             self._test_case.cleanup_phase)
@@ -367,6 +382,7 @@ class _PartialExecutor:
             phase_step.BEFORE_ASSERT__MAIN,
             phase_step_executors.BeforeAssertMainExecutor(
                 self._post_sds_main_environments(phase_identifier.BEFORE_ASSERT),
+                self._instruction_settings,
                 self._os_services),
             self._test_case.before_assert_phase)
 
@@ -399,7 +415,8 @@ class _PartialExecutor:
                               ) -> InstructionEnvironmentForPostSdsStep:
         return InstructionEnvironmentForPostSdsStep(
             self.conf_values.hds,
-            ProcessExecutionSettings(self.conf_values.timeout_in_seconds, self.exe_conf.environ),
+            ProcessExecutionSettings(self._instruction_settings.timeout_in_seconds(),
+                                     self._env_vars__read_only()),
             self.__sandbox_directory_structure,
             tmp_file_storage,
             symbols,
@@ -418,6 +435,15 @@ class _PartialExecutor:
                                 self._action_to_check_outcome,
                                 None)
 
+    def _env_vars__read_only(self) -> Optional[Mapping[str, str]]:
+        mb_environ_rw = self._instruction_settings.environ()
+        return (
+            None
+            if mb_environ_rw is None
+            else
+            MappingProxyType(mb_environ_rw)
+        )
+
 
 def _initial_atc_executor() -> Optional[ActionToCheckExecutor]:
     return None
