@@ -1,19 +1,20 @@
 from typing import List
 
-from exactly_lib.actors import common as rel_opt_conf
 from exactly_lib.common.help.syntax_contents_structure import InvokationVariant, invokation_variant_from_args
 from exactly_lib.definitions import formatting, misc_texts
 from exactly_lib.definitions.cross_ref.app_cross_ref import SeeAlsoTarget
 from exactly_lib.definitions.cross_ref.name_and_cross_ref import cross_reference_id_list
 from exactly_lib.definitions.entity import conf_params, syntax_elements, types
 from exactly_lib.definitions.entity.actors import COMMAND_LINE_ACTOR
+from exactly_lib.definitions.test_case import phase_names
 from exactly_lib.help.entities.actors.contents_structure import ActorDocumentation
 from exactly_lib.help.entities.actors.objects.common import \
     SINGLE_LINE_PROGRAM_ACT_PHASE_CONTENTS_SYNTAX_INITIAL_PARAGRAPH
 from exactly_lib.help.program_modes.common.render_syntax_contents import invokation_variants_content
 from exactly_lib.help.render import doc_utils
+from exactly_lib.impls.actors import common as rel_opt_conf
+from exactly_lib.impls.types.path import relative_path_options_documentation
 from exactly_lib.section_document.syntax import LINE_COMMENT_MARKER
-from exactly_lib.test_case_utils.documentation import relative_path_options_documentation
 from exactly_lib.util.textformat.structure import document as doc
 from exactly_lib.util.textformat.structure import structures as docs
 from exactly_lib.util.textformat.structure.core import ParagraphItem
@@ -33,7 +34,9 @@ class CommandLineActorDocumentation(ActorDocumentation):
             'executable_file': formatting.misc_name_with_formatting(misc_texts.EXECUTABLE_FILE),
             'relativity': formatting.misc_name_with_formatting(misc_texts.RELATIVITY),
             'stdout': misc_texts.STDOUT,
+            'stdin': misc_texts.STDIN,
             'os_process': misc_texts.OS_PROCESS_NAME,
+            'setup_phase': phase_names.SETUP,
         })
 
     def act_phase_contents(self) -> doc.SectionContents:
@@ -52,6 +55,10 @@ class CommandLineActorDocumentation(ActorDocumentation):
                     self._tp.text('{path:/u} {relativity:s}'),
                     self._notes_section_paragraphs(),
                 ),
+                docs.section(
+                    self._tp.text(misc_texts.STDIN.capitalize()),
+                    self._tp.fnap(_STDIN_DESCRIPTION),
+                ),
                 docs.section(
                     self._tp.text('Transformations'),
                     self._tp.fnap(_TRANSFORMATION_DESCRIPTION),
@@ -104,6 +111,13 @@ _PATH_RELATIVITY_HEADER = """\
 When {PROGRAM} has the form of the {PATH} of {executable_file:a}:
 """
 
+_STDIN_DESCRIPTION = """\
+If {PROGRAM} defines {stdin},
+then the {stdin} of the {os_process}
+is the {stdin} defined for {PROGRAM}
+followed by the {stdin} set in the {setup_phase:emphasis} phase.
+"""
+
 _TRANSFORMATION_DESCRIPTION = """\
 If {PROGRAM} includes a transformation (via a {STRING_TRANSFORMER}),
 then the transformation is applied to {stdout}
