@@ -1,9 +1,9 @@
 import functools
 from typing import List
 
+from exactly_lib.definitions.entity import types, concepts
 from exactly_lib.definitions.entity.all_entity_types import BUILTIN_SYMBOL_ENTITY_TYPE_NAMES
 from exactly_lib.definitions.entity.concepts import SYMBOL_CONCEPT_INFO
-from exactly_lib.definitions.type_system import TYPE_INFO_DICT
 from exactly_lib.help.contents_structure.entity import HtmlDocHierarchyGeneratorGetter, CliListConstructorGetter
 from exactly_lib.help.entities.builtin.contents_structure import BuiltinSymbolDocumentation
 from exactly_lib.help.render import partitioned_entity_set as pes
@@ -28,7 +28,7 @@ def _builtin_docs_of_value_type(value_type: ValueType,
 # FIXME Sort on types
 def _header(value_type: ValueType) -> str:
     return '{type_name} {symbols}'.format(
-        type_name=TYPE_INFO_DICT[value_type].name.singular.capitalize(),
+        type_name=types.VALUE_TYPE_2_TYPES_INFO_DICT[value_type].name.singular.capitalize(),
         symbols=SYMBOL_CONCEPT_INFO.name.plural)
 
 
@@ -59,10 +59,12 @@ class IndividualBuiltinSymbolConstructor(ArticleContentsConstructor):
                                                        sub_sections))
 
     def _type_paragraph(self) -> docs.ParagraphItem:
-        return docs.para('Type: ' + TYPE_INFO_DICT[self.builtin_doc.value_type].name.singular)
+        type_name = types.VALUE_TYPE_2_TYPES_INFO_DICT[self.builtin_doc.value_type].name.singular
+        return docs.para(': '.join((concepts.TYPE_CONCEPT_INFO.singular_name.capitalize(),
+                                    type_name)))
 
     def _see_also_sections(self, environment: ConstructionEnvironment) -> List[doc.SectionItem]:
-        type_info = TYPE_INFO_DICT[self.builtin_doc.value_type]
+        type_info = types.VALUE_TYPE_2_TYPES_INFO_DICT[self.builtin_doc.value_type]
         targets = [type_info.cross_reference_target] + list(self.builtin_doc.see_also)
         return see_also_sections(targets,
                                  environment)
