@@ -4,7 +4,7 @@ from exactly_lib.help.entities.concepts.contents_structure import ConceptDocumen
 from exactly_lib.help.entities.concepts.objects import \
     instruction, \
     action_to_check, actor, \
-    environment_variable, preprocessor, sds, shell_syntax, \
+    environment_variable, timeout, preprocessor, sds, shell_syntax, \
     hds, tcds, \
     suite_reporter, symbol, type_, configuration_parameter, current_working_directory, directive
 
@@ -21,6 +21,7 @@ def all_concepts() -> List[ConceptDocumentation]:
         symbol.SYMBOL_CONCEPT,
         current_working_directory.CURRENT_WORKING_DIRECTORY_CONCEPT,
         configuration_parameter.CONFIGURATION_PARAMETER_CONCEPT,
+        timeout.DOCUMENTATION,
         environment_variable.ENVIRONMENT_VARIABLE_CONCEPT,
         preprocessor.PREPROCESSOR_CONCEPT,
         suite_reporter.SUITE_REPORTER_CONCEPT,
