@@ -1,17 +1,15 @@
 from typing import List
 
 from exactly_lib import program_info
-from exactly_lib.definitions import formatting, logic
+from exactly_lib.definitions import formatting, logic, misc_texts
 from exactly_lib.definitions import syntax_descriptions
-from exactly_lib.definitions import type_system
 from exactly_lib.definitions.cross_ref.app_cross_ref import SeeAlsoTarget
 from exactly_lib.definitions.doc_format import syntax_text
-from exactly_lib.definitions.entity import syntax_elements, concepts
+from exactly_lib.definitions.entity import syntax_elements, concepts, types
 from exactly_lib.definitions.entity.concepts import SYMBOL_CONCEPT_INFO, TYPE_CONCEPT_INFO
 from exactly_lib.definitions.primitives import string_transformer
 from exactly_lib.definitions.test_case.instructions import define_symbol
 from exactly_lib.definitions.test_case.instructions import instruction_names
-from exactly_lib.definitions.type_system import TYPE_INFO_DICT
 from exactly_lib.help.entities.concepts.contents_structure import ConceptDocumentation
 from exactly_lib.symbol.symbol_syntax import symbol_reference_syntax_for_name
 from exactly_lib.symbol.value_type import ValueType
@@ -37,19 +35,17 @@ class _SymbolConcept(ConceptDocumentation):
             'symbol': SYMBOL_CONCEPT_INFO.name,
             'instruction': concepts.INSTRUCTION_CONCEPT_INFO.name,
             'symbol_name_syntax_element': syntax_elements.SYMBOL_NAME_SYNTAX_ELEMENT.argument.name,
-            'data': type_system.DATA_TYPE_CATEGORY_NAME,
-            'logic': type_system.LOGIC_TYPE_CATEGORY_NAME,
             'define_symbol': formatting.InstructionName(instruction_names.SYMBOL_DEFINITION_INSTRUCTION_NAME),
             'symbol_name_syntax': syntax_descriptions.SYMBOL_NAME_SYNTAX_DESCRIPTION,
             'def': instruction_names.SYMBOL_DEFINITION_INSTRUCTION_NAME,
 
-            'string_type_in_text': formatting.keyword(type_system.TYPE_INFO_DICT[ValueType.STRING].identifier),
+            'string_type_in_text': types.STRING_TYPE_INFO.name,
 
-            'string_type': TYPE_INFO_DICT[ValueType.STRING].identifier,
-            'list_type': TYPE_INFO_DICT[ValueType.LIST].identifier,
-            'file_trans_type': TYPE_INFO_DICT[ValueType.STRING_TRANSFORMER].identifier,
+            'string_type': types.VALUE_TYPE_2_TYPES_INFO_DICT[ValueType.STRING].identifier,
+            'list_type': types.VALUE_TYPE_2_TYPES_INFO_DICT[ValueType.LIST].identifier,
+            'file_trans_type': types.VALUE_TYPE_2_TYPES_INFO_DICT[ValueType.STRING_TRANSFORMER].identifier,
             'max_type_width': max(map(lambda type_info: len(type_info.identifier),
-                                      TYPE_INFO_DICT.values())),
+                                      types.VALUE_TYPE_2_TYPES_INFO_DICT.values())),
             'LIST_SYMBOL': list_symbol_name,
             'FILE_TRANS_SYMBOL': file_trans_symbol_name,
             'max_symbol_name_width': max(map(len, symbol_names)),
@@ -94,9 +90,10 @@ class _SymbolConcept(ConceptDocumentation):
 
             'def': instruction_names.SYMBOL_DEFINITION_INSTRUCTION_NAME,
 
-            'string_type': TYPE_INFO_DICT[ValueType.STRING].identifier,
-            'list_type': TYPE_INFO_DICT[ValueType.LIST].identifier,
-            'max_type_width': max(map(lambda value_type: len(TYPE_INFO_DICT[value_type].identifier),
+            'string_type': types.VALUE_TYPE_2_TYPES_INFO_DICT[ValueType.STRING].identifier,
+            'plain_string': misc_texts.PLAIN_STRING,
+            'list_type': types.VALUE_TYPE_2_TYPES_INFO_DICT[ValueType.LIST].identifier,
+            'max_type_width': max(map(lambda value_type: len(types.VALUE_TYPE_2_TYPES_INFO_DICT[value_type].identifier),
                                       [ValueType.LIST,
                                        ValueType.STRING])),
 
@@ -112,7 +109,9 @@ class _SymbolConcept(ConceptDocumentation):
             'rel_option': REL_symbol_OPTION,
             'ref_syntax_of_dir_name_symbol': symbol_reference_syntax_for_name('DIR_NAME_SYMBOL'),
             'ref_syntax_of_base_name_symbol': symbol_reference_syntax_for_name('BASE_NAME_SYMBOL'),
-            'ref_syntax_of_2nd_element_symbol': symbol_reference_syntax_for_name('STRING_SYMBOL'),
+            'ref_syntax_of_2nd_element_symbol': symbol_reference_syntax_for_name(
+                syntax_elements.STRING_SYNTAX_ELEMENT.singular_name + '_SYMBOL'
+            ),
 
             'special_syntax_with_invalid_symbol_name': symbol_reference_syntax_for_name('NOT/A_VALID_SYMBOL_NAME'),
             'special_syntax_with_valid_symbol_name_but_invalid_delimiter':
@@ -143,7 +142,7 @@ A {symbol} name ({symbol_name_syntax_element}) is: {symbol_name_syntax}
 """
 
 _DEFINITION = """\
-A {symbol} is defined by the {define_symbol} instruction:
+A {symbol} is defined by the {define_symbol} {instruction}:
 
 
 ```
@@ -171,12 +170,12 @@ _REFERENCE_1 = """\
 A {symbol} must be defined before it is referenced.
 
 
-Once defined, a {symbol} is available to all instructions
+Once defined, a {symbol} is available to all {instruction:s}
 following the definition - both in the phase where it is defined
 and in following phases.
 
 
-A {symbol} reference may appear in {string_type:s} and
+A {symbol} reference may appear in {string_type_in_text:s} and
 as {instruction} arguments,
 in places where an argument of a certain type is expected.
 
@@ -211,10 +210,10 @@ with the syntax of other programming languages and shell script, e.g.
 This is important since {program_name} has limited capabilities for escaping and quoting.
 
 
-Also, strings that resemble the special syntax will not be considered as errors,
-since it is assumed that these strings might have the syntax needed for a different purpose.
+Also, {plain_string:s} that resemble the special syntax will not be considered as errors,
+since it is assumed that these {plain_string:s} might have the syntax needed for a different purpose.
 
-For example, the following strings does not constitute {symbol} references,
+For example, the following {plain_string:s} does not constitute {symbol} references,
 and {program_name} will not complain:
 
 
