@@ -4,26 +4,28 @@ from exactly_lib.common.help.syntax_contents_structure import InvokationVariant,
 from exactly_lib.definitions.cross_ref.app_cross_ref import SeeAlsoTarget
 from exactly_lib.definitions.cross_ref.name_and_cross_ref import SingularNameAndCrossReferenceId
 from exactly_lib.definitions.entity.all_entity_types import SYNTAX_ELEMENT_ENTITY_TYPE_NAMES
+from exactly_lib.definitions.entity.syntax_elements import SyntaxElementInfo
+from exactly_lib.definitions.type_system import TypeCategory
 from exactly_lib.help.contents_structure.entity import EntityTypeHelp, EntityDocumentation
 from exactly_lib.impls.types.expression.grammar import Grammar
 from exactly_lib.impls.types.expression.syntax_documentation import Syntax
-from exactly_lib.symbol.value_type import TypeCategory
 from exactly_lib.util.textformat.structure import document, core
 from exactly_lib.util.textformat.structure.core import ParagraphItem
 from exactly_lib.util.textformat.structure.document import SectionContents, SectionItem
 
 
 class SyntaxElementDocumentation(EntityDocumentation):
-    def __init__(self,
-                 type_category: Optional[TypeCategory],
-                 name_and_cross_ref_target: SingularNameAndCrossReferenceId,
-                 ):
-        super().__init__(name_and_cross_ref_target)
-        self._type_category = type_category
+    def __init__(self, syntax_element: SyntaxElementInfo):
+        super().__init__(syntax_element)
+        self._syntax_element = syntax_element
+
+    @property
+    def syntax_element(self) -> SyntaxElementInfo:
+        return self._syntax_element
 
     @property
     def type_category(self) -> Optional[TypeCategory]:
-        return self._type_category
+        return self._syntax_element.type_category
 
     def main_description_rest(self) -> SectionContents:
         return SectionContents(self.main_description_rest_paragraphs(),
@@ -62,7 +64,14 @@ class SyntaxElementDocumentationWithConstantValues(SyntaxElementDocumentation):
                  syntax_element_descriptions: List[SyntaxElementDescription],
                  see_also_targets: List[SeeAlsoTarget],
                  ):
-        super().__init__(type_category, name_and_cross_ref_target)
+        super().__init__(
+            SyntaxElementInfo(
+                name_and_cross_ref_target.singular_name,
+                type_category,
+                name_and_cross_ref_target.single_line_description_str,
+                name_and_cross_ref_target.cross_reference_target,
+            )
+        )
         self._main_description_rest = main_description_rest
         self._main_description_rest_sub_sections = main_description_rest_sub_sections
         self._notes = notes
@@ -113,8 +122,7 @@ def syntax_elements_help(syntax_elements: Iterable[SyntaxElementDocumentation])
                           syntax_elements)
 
 
-def for_type_with_grammar(type_category_for_help: TypeCategory,
-                          type_info: SingularNameAndCrossReferenceId,
+def for_type_with_grammar(type_info: SyntaxElementInfo,
                           grammar: Grammar) -> SyntaxElementDocumentation:
     syntax = Syntax(grammar)
 
@@ -125,7 +133,7 @@ def for_type_with_grammar(type_category_for_help: TypeCategory,
     description = grammar.description()
 
     return syntax_element_documentation(
-        type_category_for_help,
+        type_info.type_category,
         type_info,
         description.initial_paragraphs,
         description.sections,
