@@ -1,38 +1,50 @@
 from typing import List
 
 from exactly_lib.common.help.syntax_contents_structure import InvokationVariant, SyntaxElementDescription
-from exactly_lib.definitions import formatting, misc_texts
+from exactly_lib.definitions import misc_texts
 from exactly_lib.definitions import path
 from exactly_lib.definitions import syntax_descriptions
+from exactly_lib.definitions.cross_ref.app_cross_ref import SeeAlsoTarget
 from exactly_lib.definitions.cross_ref.name_and_cross_ref import cross_reference_id_list
 from exactly_lib.definitions.entity import syntax_elements, types, concepts
 from exactly_lib.definitions.test_case.instructions import define_symbol
 from exactly_lib.help.entities.syntax_elements.contents_structure import SyntaxElementDocumentation
-from exactly_lib.symbol.value_type import TypeCategory
+from exactly_lib.symbol import value_type
 from exactly_lib.util.cli_syntax.elements import argument as a
 from exactly_lib.util.parse import token
+from exactly_lib.util.textformat.structure.core import ParagraphItem
+from exactly_lib.util.textformat.structure.document import SectionItem
 from exactly_lib.util.textformat.textformat_parser import TextParser
 
 
 class _Documentation(SyntaxElementDocumentation):
     def __init__(self):
-        super().__init__(TypeCategory.DATA,
-                         syntax_elements.STRING_SYNTAX_ELEMENT)
-
+        super().__init__(syntax_elements.STRING_SYNTAX_ELEMENT)
+        the_string_type = 'the ' + types.STRING_TYPE_INFO.singular_name
+        non_str_types_w_str_conversion = value_type.sorted_types(
+            set(value_type.VALUE_TYPES_W_STR_RENDERING) -
+            {value_type.ValueType.STRING}
+        )
         self._tp = TextParser({
-            'string_type': formatting.keyword(types.STRING_TYPE_INFO.name.singular),
-            'list_type': formatting.keyword(types.LIST_TYPE_INFO.name.singular),
-            'path_type': formatting.keyword(types.PATH_TYPE_INFO.name.singular),
-            'symbol': formatting.concept_(concepts.SYMBOL_CONCEPT_INFO),
-            'CHR': 'CHARACTER',
-            'whitespace': misc_texts.WHITESPACE,
+            'symbol': concepts.SYMBOL_CONCEPT_INFO.name,
+            'symbol_reference': syntax_elements.SYMBOL_REFERENCE_SYNTAX_ELEMENT.singular_name,
+            'type': concepts.TYPE_CONCEPT_INFO.name,
+            'string_type': types.STRING_TYPE_INFO.name,
+            'list_type': types.LIST_TYPE_INFO.name,
+            'path_type': types.PATH_TYPE_INFO.name,
+
+            'A_ref_to_symbol_w_string_conversion': types.a_ref_to_a_symbol_w_string_conversion__sentence(),
+            'non_str_types_w_str_rendering': types.types__and_list(non_str_types_w_str_conversion),
+
+            'soft_quote': syntax_descriptions.SOFT_QUOTE_NAME,
+            'hard_quote': syntax_descriptions.HARD_QUOTE_NAME,
             'SOFT_Q': token.SOFT_QUOTE_CHAR,
             'HARD_Q': token.HARD_QUOTE_CHAR,
+            'CHR': 'CHARACTER',
+            'whitespace': misc_texts.WHITESPACE,
 
-            'soft_quotes': formatting.concept(syntax_descriptions.SOFT_QUOTE_NAME.plural),
-            'hard_quotes': formatting.concept(syntax_descriptions.HARD_QUOTE_NAME.plural),
-            'Sym_refs_are_substituted': syntax_descriptions.symbols_are_substituted_in('the string'),
-            'Sym_refs_are_not_substituted': syntax_descriptions.symbols_are_not_substituted_in('the string'),
+            'Sym_refs_are_substituted': syntax_descriptions.symbols_are_substituted_in(the_string_type),
+            'Sym_refs_are_not_substituted': syntax_descriptions.symbols_are_not_substituted_in(the_string_type),
             'REL_CD_OPTION': path.REL_CWD_OPTION,
         })
 
@@ -46,15 +58,27 @@ class _Documentation(SyntaxElementDocumentation):
                               self._tp.fnap(_DESCRIPTION_OF_HARD_Q)),
         ]
 
-    def syntax_element_descriptions(self) -> list:
+    def syntax_element_descriptions(self) -> List[SyntaxElementDescription]:
         return [
             self._symbol_reference_sed(),
         ]
 
-    def main_description_rest_paragraphs(self) -> list:
+    def main_description_rest_paragraphs(self) -> List[ParagraphItem]:
         return []
 
-    def see_also_targets(self) -> list:
+    def main_description_rest_sub_sections(self) -> List[SectionItem]:
+        return [
+            self._tp.section(
+                'Concatenation',
+                _DESCRIPTION__CONCATENATION,
+            ),
+            self._tp.section(
+                'Conversion of {non_str_types_w_str_rendering}',
+                _DESCRIPTION__TYPE_CONVERSION,
+            ),
+        ]
+
+    def see_also_targets(self) -> List[SeeAlsoTarget]:
         info_refs = cross_reference_id_list([
             syntax_elements.SYMBOL_REFERENCE_SYNTAX_ELEMENT,
             types.STRING_TYPE_INFO,
@@ -72,7 +96,7 @@ class _Documentation(SyntaxElementDocumentation):
                                         self._tp.fnap(_SYMBOL_REFERENCE_DESCRIPTION))
 
     @staticmethod
-    def _cl_arguments() -> list:
+    def _cl_arguments() -> List[a.ArgumentUsage]:
         return [
             a.Choice.of_single_argument_choices(
                 a.Multiplicity.ZERO_OR_MORE,
@@ -96,28 +120,39 @@ A "naked" sequence of characters.
 """
 
 _DESCRIPTION_OF_SOFT_Q = """\
-Characters surrounded by {soft_quotes} ({SOFT_Q}).
+Characters surrounded by {soft_quote:s/q} ({SOFT_Q}).
 
 
 {Sym_refs_are_substituted}
 """
 
 _DESCRIPTION_OF_HARD_Q = """\
-Characters surrounded by {hard_quotes} ({HARD_Q}).
+Characters surrounded by {hard_quote:s/q} ({HARD_Q}).
 
 
 {Sym_refs_are_not_substituted}
 """
 
 _SYMBOL_REFERENCE_DESCRIPTION = """\
-A reference to a {symbol} defined as either {string_type}, {list_type} or {path_type}.
+{A_ref_to_symbol_w_string_conversion}
+"""
 
+_DESCRIPTION__CONCATENATION = """\
+{string_type:/u} fragments of the different forms may be concatenated
+by putting them side by side (without intervening {whitespace}).
+"""
 
-An empty {list_type} value is rendered as an empty string.
+_DESCRIPTION__TYPE_CONVERSION = """\
+References to these {type:s} can be converted to {string_type:s},
+either by putting the {symbol_reference} inside {soft_quote:s},
+or by using a naked {symbol_reference} (in most places).
 
 
-A non-empty {list_type} value is rendered by separating the elements with a single space.
+An empty {list_type:/q} is rendered as an empty {string_type}.
 
 
-A {path_type} value is rendered as absolute paths (even if relativity is {REL_CD_OPTION}).
+A non-empty {list_type:/q} is rendered by separating the elements with a single space.
+
+
+{path_type:a/qu} is rendered as an absolute path (even if relativity is {REL_CD_OPTION}).
 """
