@@ -1,8 +1,8 @@
 from typing import List
 
+from exactly_lib.definitions.type_system import TypeCategory
 from exactly_lib.help.entities.types.contents_structure import TypeDocumentation
 from exactly_lib.help.entities.types.objects import data_types, logic_types
-from exactly_lib.symbol.value_type import TypeCategory
 
 
 def all_types() -> List[TypeDocumentation]:
@@ -16,6 +16,7 @@ def all_types() -> List[TypeDocumentation]:
         logic_types.LINE_MATCHER_DOCUMENTATION,
         logic_types.FILE_MATCHER_DOCUMENTATION,
         logic_types.FILES_MATCHER_DOCUMENTATION,
+        logic_types.STRING_SOURCE_DOCUMENTATION,
         logic_types.STRING_MATCHER_DOCUMENTATION,
         logic_types.STRING_TRANSFORMER_DOCUMENTATION,
         logic_types.PROGRAM_DOCUMENTATION,
