@@ -1,12 +1,10 @@
-from exactly_lib.common.help.documentation_text import POSIX_SYNTAX
-from exactly_lib.definitions import formatting
+from exactly_lib.definitions import formatting, misc_texts
 from exactly_lib.definitions.current_directory_and_path_type import path_type_path_rendering
 from exactly_lib.definitions.entity import concepts
 from exactly_lib.definitions.entity import types, syntax_elements
 from exactly_lib.definitions.formatting import InstructionName
 from exactly_lib.definitions.test_case.instructions import instruction_names
 from exactly_lib.help.entities.types.contents_structure import TypeDocumentation, TypeWithExpressionGrammarDocumentation
-from exactly_lib.symbol.value_type import TypeCategory
 from exactly_lib.util.textformat.structure.document import SectionContents
 from exactly_lib.util.textformat.textformat_parser import TextParser
 
@@ -19,32 +17,26 @@ and for the {run} instruction, e.g.
 """
 
 _STRING_MAIN_DESCRIPTION_REST = """\
-Used for arbitrary string values, and relative file names.
- 
- 
-When used as a relative file name, {POSIX_SYNTAX} should be used.
+Used for arbitrary {plain_string} values, relative file names etc.
 """
 
 _TEXT_PARSER = TextParser({
     'run': InstructionName(instruction_names.RUN_INSTRUCTION_NAME),
-    'POSIX_SYNTAX': POSIX_SYNTAX,
     'ATC': formatting.concept_(concepts.ACTION_TO_CHECK_CONCEPT_INFO),
+    'plain_string': misc_texts.PLAIN_STRING,
 })
 
-STRING_DOCUMENTATION = TypeDocumentation(TypeCategory.DATA,
-                                         types.STRING_TYPE_INFO,
+STRING_DOCUMENTATION = TypeDocumentation(types.STRING_TYPE_INFO,
                                          syntax_elements.STRING_SYNTAX_ELEMENT,
                                          _TEXT_PARSER.section_contents(_STRING_MAIN_DESCRIPTION_REST)
                                          )
 
-LIST_DOCUMENTATION = TypeDocumentation(TypeCategory.DATA,
-                                       types.LIST_TYPE_INFO,
+LIST_DOCUMENTATION = TypeDocumentation(types.LIST_TYPE_INFO,
                                        syntax_elements.LIST_SYNTAX_ELEMENT,
                                        _TEXT_PARSER.section_contents(_LIST_MAIN_DESCRIPTION_REST)
                                        )
 
-PATH_DOCUMENTATION = TypeDocumentation(TypeCategory.DATA,
-                                       types.PATH_TYPE_INFO,
+PATH_DOCUMENTATION = TypeDocumentation(types.PATH_TYPE_INFO,
                                        syntax_elements.PATH_SYNTAX_ELEMENT,
                                        SectionContents([],
                                                        [
@@ -55,6 +47,5 @@ PATH_DOCUMENTATION = TypeDocumentation(TypeCategory.DATA,
                                        ]
                                        )
 FILES_CONDITION_DOCUMENTATION = TypeWithExpressionGrammarDocumentation(
-    TypeCategory.DATA,
     types.FILES_CONDITION_TYPE_INFO,
     syntax_elements.FILES_CONDITION_SYNTAX_ELEMENT)
