@@ -3,6 +3,7 @@ import functools
 from exactly_lib.definitions import type_system
 from exactly_lib.definitions.entity.all_entity_types import TYPE_ENTITY_TYPE_NAMES
 from exactly_lib.definitions.test_case import phase_names
+from exactly_lib.definitions.type_system import TypeCategory
 from exactly_lib.help.contents_structure.entity import HtmlDocHierarchyGeneratorGetter, CliListConstructorGetter
 from exactly_lib.help.entities.types import all_types
 from exactly_lib.help.entities.types.contents_structure import TypeDocumentation
@@ -12,7 +13,6 @@ from exactly_lib.help.render.doc_utils import synopsis_section
 from exactly_lib.help.render.entity_docs import \
     single_line_description_as_summary_paragraphs
 from exactly_lib.help.render.see_also import see_also_sections
-from exactly_lib.symbol.value_type import TypeCategory
 from exactly_lib.util.textformat.constructor.environment import ConstructionEnvironment
 from exactly_lib.util.textformat.constructor.section import \
     ArticleContentsConstructor
@@ -21,9 +21,9 @@ from exactly_lib.util.textformat.structure import structures as docs
 from exactly_lib.util.textformat.textformat_parser import TextParser
 from exactly_lib.util.textformat.utils import append_section_if_contents_is_non_empty
 
-LOGIC_TYPES_HEADER = type_system.LOGIC_TYPE_CATEGORY_NAME.capitalize() + ' types'
+LOGIC_TYPES_HEADER = type_system.LOGIC_TYPE_CATEGORY_NAME.capitalize()
 
-DATA_TYPES_HEADER = type_system.DATA_TYPE_CATEGORY_NAME.capitalize() + ' types'
+DATA_TYPES_HEADER = type_system.DATA_TYPE_CATEGORY_NAME.capitalize()
 
 _PARTITIONS_SETUP = [
     pes.PartitionSetup(pes.PartitionNamesSetup('data-type',
