@@ -1,10 +1,11 @@
 from exactly_lib import program_info
-from exactly_lib.definitions import formatting, type_system, misc_texts
+from exactly_lib.definitions import formatting, misc_texts
 from exactly_lib.definitions import test_case_file_structure
-from exactly_lib.definitions.entity import concepts, types, conf_params
+from exactly_lib.definitions.entity import concepts, types
 from exactly_lib.definitions.formatting import InstructionName
 from exactly_lib.definitions.test_case import phase_names, phase_infos
 from exactly_lib.definitions.test_case.instructions import instruction_names
+from exactly_lib.help.entities.concepts.objects import environment_variable
 from exactly_lib.help.render import see_also
 from exactly_lib.util.textformat.constructor import paragraphs
 from exactly_lib.util.textformat.constructor import sections
@@ -39,14 +40,17 @@ def root(header: str) -> generator.SectionHierarchyGenerator:
 
         'act_hds_conf_param': formatting.conf_param(test_case_file_structure.HDS_ACT_INFO.identifier),
 
-        'data': type_system.DATA_TYPE_CATEGORY_NAME,
-        'path_type': formatting.term(types.PATH_TYPE_INFO.singular_name),
+        'path_type': types.PATH_TYPE_INFO.name,
 
         'symbol_concept': formatting.concept_(concepts.SYMBOL_CONCEPT_INFO),
         'def_instruction': InstructionName(instruction_names.SYMBOL_DEFINITION_INSTRUCTION_NAME),
 
         'os_process': misc_texts.OS_PROCESS_NAME,
-        'time_out_conf_param': formatting.conf_param_(conf_params.TIMEOUT_CONF_PARAM_INFO),
+        'env_var': concepts.ENVIRONMENT_VARIABLE_CONCEPT_INFO.name,
+        'timeout': concepts.TIMEOUT_CONCEPT_INFO.name,
+        'timeout_instruction': InstructionName(instruction_names.TIMEOUT_INSTRUCTION_NAME),
+        'type': concepts.TYPE_CONCEPT_INFO.name,
+        'instruction': concepts.INSTRUCTION_CONCEPT_INFO.name,
 
         'relativity': formatting.concept(misc_texts.RELATIVITY.singular),
         'relativities': formatting.concept(misc_texts.RELATIVITY.plural),
@@ -119,8 +123,8 @@ def root(header: str) -> generator.SectionHierarchyGenerator:
                     ),
                     const_paragraphs_child(
                         'env-vars',
-                        'Environment variables',
-                        tp.fnap(_OS_PROC_ENVIRONMENT_VARIABLES),
+                        tp.format('{env_var:s/u}'),
+                        environment_variable.common_description(),
                     ),
                     const_paragraphs_child(
                         'timeout',
@@ -213,17 +217,17 @@ They can be changed by the {conf_phase} phase.
 ############################################################
 _FILE_REFERENCES = """\
 {program_name} has functionality for referencing files in the
-{TCDS} using the {path_type} type.
+{TCDS} using the {path_type:/q} {type}.
 
 
-The {path_type} {data} type has syntax for expressing paths relative to any of the {TCDS} directories.
+The {path_type:/q} {type} has syntax for expressing paths relative to any of the {TCDS} directories.
   
 
-The directory that a {path_type} value is relative to is called the
+The directory that {path_type:a/q} value is relative to is called the
 {relativity} of the value.
 
 
-Arguments to instructions that are paths use the {path_type} {data} type.
+Arguments to {instruction:s} that are paths use the {path_type:/q} {type}.
 
 Each argument have different accepted {relativities}
 and
@@ -286,15 +290,6 @@ Part of their environment is controlled by {program_name}.
 # - Which env vars are available.
 # - Manipulating env vars
 ############################################################
-_OS_PROC_ENVIRONMENT_VARIABLES = """\
-All OS environment variables
-that are set when {program_name} is started
-are available in {os_process:s} run from the test case.
-
-
-Environment variables can be manipulated by the {env} instruction.
-"""
-
 _OS_PROC_CURRENT_DIRECTORY = """\
 The current directory (PWD) is the same as for instructions.
 
@@ -303,7 +298,7 @@ It is changed by the {cd} instruction.
 """
 
 _OS_PROC_TIMEOUT = """\
-Timeout for all {os_process:s} is determined by the {conf_param} {time_out_conf_param}.
+{timeout:/u} for all {os_process:s} can be set by the {timeout_instruction} {instruction}.
 """
 
 
@@ -312,5 +307,7 @@ def _os_process_see_also_targets() -> List[see_also.SeeAlsoTarget]:
         concepts.TCDS_CONCEPT_INFO.cross_reference_target,
         concepts.CURRENT_WORKING_DIRECTORY_CONCEPT_INFO.cross_reference_target,
         concepts.ENVIRONMENT_VARIABLE_CONCEPT_INFO.cross_reference_target,
-        conf_params.TIMEOUT_CONF_PARAM_INFO.cross_reference_target,
+        concepts.TIMEOUT_CONCEPT_INFO.cross_reference_target,
+        phase_infos.SETUP.instruction_cross_reference_target(instruction_names.ENV_VAR_INSTRUCTION_NAME),
+        phase_infos.SETUP.instruction_cross_reference_target(instruction_names.TIMEOUT_INSTRUCTION_NAME),
     ]
