@@ -1,9 +1,9 @@
 from exactly_lib.test_case.app_env import ApplicationEnvironment
 from exactly_lib.test_case.os_services import OsServices
 from exactly_lib.test_case.phases.instruction_environment import InstructionEnvironmentForPostSdsStep
-from exactly_lib.type_val_deps.dep_variants.sdv import resolving_helper
-from exactly_lib.type_val_deps.dep_variants.sdv.resolving_helper import LogicTypeResolvingHelper
-from exactly_lib.type_val_deps.envs.resolving_environment import FullResolvingEnvironment
+from exactly_lib.type_val_deps.dep_variants.sdv.full_deps import resolving_helper
+from exactly_lib.type_val_deps.dep_variants.sdv.full_deps.resolving_environment import FullResolvingEnvironment
+from exactly_lib.type_val_deps.dep_variants.sdv.full_deps.resolving_helper import LogicTypeResolvingHelper
 
 
 def resolving_helper_for_instruction_env(os_services: OsServices,
