@@ -1,5 +1,6 @@
 from typing import List
 
+from exactly_lib.common.help import headers
 from exactly_lib.definitions import misc_texts
 from exactly_lib.definitions.entity import types, syntax_elements
 from exactly_lib.impls.types.program.help_texts import TRANSFORMATION_ARE_IGNORED__TMPL
@@ -12,6 +13,7 @@ def run_program_matcher_description(exe_env: List[ParagraphItem]) -> List[Paragr
         'program': types.PROGRAM_TYPE_INFO.name,
         'PROGRAM': syntax_elements.PROGRAM_SYNTAX_ELEMENT.singular_name,
         'exit_code': misc_texts.EXIT_CODE,
+        'Note': headers.NOTE_LINE_HEADER,
     })
     return (
             tp.fnap(_HEADER) +
