@@ -1,3 +1,4 @@
+from exactly_lib.definitions.entity import syntax_elements
 from exactly_lib.definitions.primitives import program, string_transformer
 from exactly_lib.util.cli_syntax.elements import argument as a
 
@@ -9,6 +10,7 @@ RUN_WITH_IGNORED_EXIT_CODE_OPTION_NAME = program.WITH_IGNORED_EXIT_CODE_OPTION_N
 
 REPLACE_TRANSFORMER_NAME = 'replace'
 FILTER_TRANSFORMER_NAME = 'filter'
+GREP_TRANSFORMER_NAME = 'grep'
 
 RANGE_EXPR_SED_NAME = 'LINE-NUMBER-RANGE'
 LINE_NUMBERS_FILTER_OPTION = a.Option(a.OptionName('line-nums'))
@@ -25,5 +27,9 @@ STRIP_TRAILING_NEW_LINES_OPTION_NAME = a.OptionName(long_name='trailing-new-line
 
 TCDS_PATH_REPLACEMENT = 'replace-test-case-dirs'
 
+LINES_SELECTION_OPTION_NAME = a.OptionName(long_name='at')
+LINES_SELECTION_OPTION = a.Option(LINES_SELECTION_OPTION_NAME,
+                                  syntax_elements.LINE_MATCHER_SYNTAX_ELEMENT.singular_name)
+
 PRESERVE_NEW_LINES_OPTION_NAME = a.OptionName(long_name='preserve-new-lines')
 PRESERVE_NEW_LINES_OPTION = a.Option(PRESERVE_NEW_LINES_OPTION_NAME)
