@@ -5,6 +5,7 @@ from exactly_lib.test_case.os_services import OsServices
 from exactly_lib.test_case.phases.common import TestCaseInstructionWithSymbols
 from exactly_lib.test_case.phases.instruction_environment import InstructionEnvironmentForPreSdsStep, \
     InstructionEnvironmentForPostSdsStep
+from exactly_lib.test_case.phases.instruction_settings import InstructionSettings
 from exactly_lib.test_case.result import sh, svh
 
 
@@ -29,6 +30,7 @@ class BeforeAssertPhaseInstruction(TestCaseInstructionWithSymbols):
 
     def main(self,
              environment: InstructionEnvironmentForPostSdsStep,
+             settings: InstructionSettings,
              os_services: OsServices) -> sh.SuccessOrHardError:
         """
         :raises: :class:`HardErrorException`
