@@ -1,7 +1,7 @@
 from abc import ABC, abstractmethod
 
 from exactly_lib.test_case.phases.act.adv_w_validation import AdvWValidation
-from exactly_lib.test_case.phases.act.execution_input import ActExecutionInput
+from exactly_lib.test_case.phases.act.execution_input import AtcExecutionInput
 from exactly_lib.test_case.phases.setup.settings_builder import SetupSettingsBuilder
 
 
@@ -13,6 +13,6 @@ class SetupSettingsHandler(ABC):
         pass
 
     @abstractmethod
-    def as_act_execution_input(self) -> AdvWValidation[ActExecutionInput]:
+    def as_atc_execution_input(self) -> AdvWValidation[AtcExecutionInput]:
         """Gives the contents of the handled builder, as Act Execution Input"""
         pass
