@@ -106,7 +106,7 @@ class SuitesExecutor:
 
     def _process_single_sub_suite(self, suite: structure.TestSuiteHierarchy):
         """
-        Executes a single suite (i.e. not it's sub suites).
+        Executes a single suite (i.e. not its sub suites).
         """
         sub_suite_reporter = self._reporter.new_sub_suite_reporter(suite)
         sub_suite_reporter.progress_reporter.suite_begin()
@@ -127,6 +127,7 @@ class SuitesExecutor:
             self._default_case_configuration.test_case_definition,
             suite.test_case_handling_setup,
             self._default_case_configuration.os_services,
+            self._default_case_configuration.mem_buff_size,
             self._default_case_configuration.is_keep_sandbox,
             self._default_case_configuration.sandbox_root_dir_resolver)
 
