@@ -1,4 +1,3 @@
-import types
 from typing import TypeVar, Optional, Callable, List, Sequence
 
 T = TypeVar('T')
@@ -18,7 +17,7 @@ class Composition:
         return self.g(self.f(arg))
 
 
-def and_predicate(predicates: List[Callable[[T], bool]]) -> types.FunctionType:
+def and_predicate(predicates: List[Callable[[T], bool]]) -> Callable[[T], bool]:
     if not predicates:
         return lambda x: True
     if len(predicates) == 1:
@@ -46,6 +45,15 @@ def map_optional(f: Callable[[T], U], x: Optional[T]) -> Optional[U]:
     )
 
 
+def optional_as_list(x: Optional[T]) -> List[T]:
+    return (
+        []
+        if x is None
+        else
+        [x]
+    )
+
+
 def reduce_optional(f: Callable[[T], U], value_if_none: U, x: Optional[T]) -> U:
     return (
         value_if_none
@@ -55,6 +63,15 @@ def reduce_optional(f: Callable[[T], U], value_if_none: U, x: Optional[T]) -> U:
     )
 
 
+def reduce_optional_2(x: Optional[T], value_if_none: T) -> U:
+    return (
+        value_if_none
+        if x is None
+        else
+        x
+    )
+
+
 def filter_not_none(xs: Sequence[Optional[T]]) -> List[T]:
     return [
         x
