@@ -1,7 +1,6 @@
 import subprocess
-from abc import ABC, abstractmethod
-from typing import IO, Union, TypeVar, Generic
 
+from exactly_lib.util.file_utils.std import StdFiles
 from exactly_lib.util.process_execution.execution_elements import Executable, ProcessExecutionSettings
 
 
@@ -14,16 +13,11 @@ class ProcessExecutionException(Exception):
         return self._cause
 
 
-ProcessExecutionFile = Union[None, int, IO]
-
-
 class ProcessExecutor:
     def execute(self,
                 executable: Executable,
                 settings: ProcessExecutionSettings,
-                stdin: ProcessExecutionFile,
-                stdout: ProcessExecutionFile,
-                stderr: ProcessExecutionFile,
+                files: StdFiles,
                 ) -> int:
         """
         :return: Exit code from successful execution
@@ -32,9 +26,9 @@ class ProcessExecutor:
         try:
             return subprocess.call(
                 executable.arg_list_or_str,
-                stdin=stdin,
-                stdout=stdout,
-                stderr=stderr,
+                stdin=files.stdin,
+                stdout=files.output.out,
+                stderr=files.output.err,
                 env=settings.environ,
                 timeout=settings.timeout_in_seconds,
                 shell=executable.is_shell,
@@ -45,18 +39,3 @@ class ProcessExecutor:
             raise ProcessExecutionException(ex)
         except subprocess.TimeoutExpired as ex:
             raise ProcessExecutionException(ex)
-
-
-T = TypeVar('T')
-
-
-class ExecutableExecutor(Generic[T], ABC):
-    @abstractmethod
-    def execute(self,
-                settings: ProcessExecutionSettings,
-                executable: Executable,
-                ) -> T:
-        """
-        :raises ProcessExecutionException: Unable to execute the program.
-        """
-        pass
