@@ -1,12 +1,17 @@
+from abc import ABC, abstractmethod
+from typing import TypeVar, Generic
+
 from exactly_lib.util.textformat.structure.core import ParagraphItem
 from exactly_lib.util.textformat.structure.lists import HeaderContentList
 from exactly_lib.util.textformat.structure.literal_layout import LiteralLayout
 from exactly_lib.util.textformat.structure.paragraph import Paragraph
 from exactly_lib.util.textformat.structure.table import Table
 
+T = TypeVar('T')
 
-class ParagraphItemVisitor:
-    def visit(self, item: ParagraphItem):
+
+class ParagraphItemVisitor(Generic[T], ABC):
+    def visit(self, item: ParagraphItem) -> T:
         if isinstance(item, Paragraph):
             return self.visit_paragraph(item)
         if isinstance(item, HeaderContentList):
@@ -17,14 +22,18 @@ class ParagraphItemVisitor:
             return self.visit_table(item)
         raise TypeError('Unknown {}: {}'.format(ParagraphItem.__name__, str(type(item))))
 
-    def visit_paragraph(self, paragraph: Paragraph):
-        raise NotImplemented()
+    @abstractmethod
+    def visit_paragraph(self, paragraph: Paragraph) -> T:
+        pass
 
-    def visit_header_value_list(self, header_value_list: HeaderContentList):
-        raise NotImplemented()
+    @abstractmethod
+    def visit_header_value_list(self, header_value_list: HeaderContentList) -> T:
+        pass
 
-    def visit_literal_layout(self, x: LiteralLayout):
-        raise NotImplemented()
+    @abstractmethod
+    def visit_literal_layout(self, x: LiteralLayout) -> T:
+        pass
 
-    def visit_table(self, table: Table):
-        raise NotImplemented()
+    @abstractmethod
+    def visit_table(self, table: Table) -> T:
+        pass
